import * as React from 'react';
export interface IThemeProviderProps<TScheme, TTheme> {
    scheme?: TScheme;
    theme?: TTheme;
}
export interface ICustomizerProps<TContext> {
    /**
     * Optional transform function for context. Any implementations should take care to return context without
     * mutating it.
     */
    contextTransform?: (context: Readonly<TContext>) => TContext;
}
export interface IThemeProviders<TContext, TTheme, TScheme, TCustomizerProps extends ICustomizerProps<TContext>> {
    /**
     * A provider that applies the given scheme to the given context and returns the resutling context. This provider
     * should automatically handle falling back to theme data from the global store (outside of context) if applicable.
     */
    getThemedContext: (context: TContext, scheme?: TScheme, theme?: TTheme) => TContext;
    /**
     * A customizer component that supplies the underlying implementation for themeProvider.
     */
    CustomizerComponent: React.ComponentType<TCustomizerProps>;
}
/**
 * Theme provider is a simplified version of Customizer that activates the appropriate theme data
 * for a given scheme name.
 *
 * @param providers - Injected providers for accessing theme data and providing it via a Customizer component.
 */
export declare function themeProvider<TContext, TTheme, TScheme, TCustomizerProps extends ICustomizerProps<TContext>>(providers: IThemeProviders<TContext, TTheme, TScheme, TCustomizerProps>): React.StatelessComponent<IThemeProviderProps<TScheme, TTheme>>;
